@@ -106,10 +106,8 @@ class LVMSimpleForm(NetBoxModelForm):
         storage_configuration = super().save(*args, **kwargs)
 
         drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
-        partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
-                                             type='Linux LVM', description='Partition 1 on SSD Cluster')
         volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        physicalvolume = PhysicalVolume.objects.create(partition=partition, pv_name=drive.device_name(), vg=volumegroup)
+        physicalvolume = PhysicalVolume.objects.create(device=drive, pv_name=drive.device_name(), vg=volumegroup)
         logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
                                                      lv_name=self.cleaned_data['lv_name'],
                                                      size=self.cleaned_data['size'],
@@ -123,7 +121,6 @@ class LVMSimpleForm(NetBoxModelForm):
 
         print("Instances")
         print(drive)
-        print(partition)
         print(volumegroup)
         print(physicalvolume)
         print(logicalvolume)
