@@ -43,13 +43,13 @@ from netbox_storage.views import (
 from netbox_storage.views.linux_device import LinuxDeviceListView, LinuxDeviceEditView, LinuxDeviceBulkImportView, \
     LinuxDeviceBulkEditView, LinuxDeviceBulkDeleteView, LinuxDeviceView, LinuxDeviceDeleteView
 from netbox_storage.views.logical_volume import LogicalVolumeDeleteView, LogicalVolumeEditView, LogicalVolumeView, \
-    LogicalVolumeListView
+    LogicalVolumeListView, LogicalVolumeBulkImportView, LogicalVolumeBulkEditView, LogicalVolumeBulkDeleteView
 from netbox_storage.views.physical_volume import PhysicalVolumeDeleteView, PhysicalVolumeEditView, PhysicalVolumeView, \
     PhysicalVolumeListView, PhysicalVolumeBulkImportView, PhysicalVolumeBulkEditView, PhysicalVolumeBulkDeleteView
 from netbox_storage.views.template import LVMAddTemplateView, AddTemplateDriveView, \
     AddTemplatePartitionView
 from netbox_storage.views.volume_group import VolumeGroupDeleteView, VolumeGroupEditView, VolumeGroupView, \
-    VolumeGroupListView
+    VolumeGroupListView, VolumeGroupBulkImportView, VolumeGroupBulkEditView, VolumeGroupBulkDeleteView
 
 app_name = "netbox_storage"
 
@@ -145,9 +145,9 @@ urlpatterns = [
     #
     path("logicalvolume/", LogicalVolumeListView.as_view(), name="logicalvolume_list"),
     path("logicalvolume/add/", LogicalVolumeEditView.as_view(), name="logicalvolume_add"),
-    # path("logicalvolume/import/", LogicalVolumeBulkImportView.as_view(), name="logicalvolume_import"),
-    # path("logicalvolume/edit/", LogicalVolumeBulkEditView.as_view(), name="logicalvolume_bulk_edit"),
-    # path("logicalvolume/delete/", LogicalVolumeBulkDeleteView.as_view(), name="logicalvolume_bulk_delete"),
+    path("logicalvolume/import/", LogicalVolumeBulkImportView.as_view(), name="logicalvolume_import"),
+    path("logicalvolume/edit/", LogicalVolumeBulkEditView.as_view(), name="logicalvolume_bulk_edit"),
+    path("logicalvolume/delete/", LogicalVolumeBulkDeleteView.as_view(), name="logicalvolume_bulk_delete"),
     path("logicalvolume/<int:pk>/", LogicalVolumeView.as_view(), name="logicalvolume"),
     path("logicalvolume/<int:pk>/edit/", LogicalVolumeEditView.as_view(), name="logicalvolume_edit"),
     path("logicalvolume/<int:pk>/delete/", LogicalVolumeDeleteView.as_view(), name="logicalvolume_delete"),
@@ -162,9 +162,9 @@ urlpatterns = [
     #
     path("volumegroup/", VolumeGroupListView.as_view(), name="volumegroup_list"),
     path("volumegroup/add/", VolumeGroupEditView.as_view(), name="volumegroup_add"),
-    # path("volumegroup/import/", VolumeGroupBulkImportView.as_view(), name="volumegroup_import"),
-    # path("volumegroup/edit/", VolumeGroupBulkEditView.as_view(), name="volumegroup_bulk_edit"),
-    # path("volumegroup/delete/", VolumeGroupBulkDeleteView.as_view(), name="volumegroup_bulk_delete"),
+    path("volumegroup/import/", VolumeGroupBulkImportView.as_view(), name="volumegroup_import"),
+    path("volumegroup/edit/", VolumeGroupBulkEditView.as_view(), name="volumegroup_bulk_edit"),
+    path("volumegroup/delete/", VolumeGroupBulkDeleteView.as_view(), name="volumegroup_bulk_delete"),
     path("volumegroup/<int:pk>/", VolumeGroupView.as_view(), name="volumegroup"),
     path("volumegroup/<int:pk>/edit/", VolumeGroupEditView.as_view(), name="volumegroup_edit"),
     path("volumegroup/<int:pk>/delete/", VolumeGroupDeleteView.as_view(), name="volumegroup_delete"),
